@@ -4,7 +4,7 @@
 """
 ===============================================================================
 
-    Copyright (C) 2009-2018 Rudolf Cardinal (rudolf@pobox.com).
+    Original code copyright (C) 2009-2018 Rudolf Cardinal (rudolf@pobox.com).
 
     This file is part of cardinal_pythonlib.
 
@@ -22,7 +22,7 @@
 
 ===============================================================================
 
-Support functions to do with the core language.
+**Support functions to handle OS signals that may cause trouble.**
 
 """
 
@@ -40,43 +40,72 @@ log.addHandler(logging.NullHandler())
 
 # noinspection PyUnusedLocal
 def ctrl_c_trapper(signum: int, stackframe) -> None:
+    """
+    Logs that ``CTRL-C`` has been pressed but does nothing else.
+    """
     log.critical("Ignoring CTRL+C (signal {}); use the GUI to quit".format(
         signum))
 
 
 # noinspection PyUnusedLocal
 def ctrl_break_trapper(signum: int, stackframe) -> None:
+    """
+    Logs that ``CTRL-BREAK`` has been pressed but does nothing else.
+    """
     log.critical("Ignoring CTRL+BREAK (signal {}); use the GUI to quit".format(
         signum))
 
 
 # noinspection PyUnusedLocal
 def sigterm_trapper(signum: int, stackframe) -> None:
+    """
+    Logs that ``SIGTERM`` has been received but does nothing else.
+    """
     log.critical("Ignoring SIGTERM (signal {}); use the GUI to quit".format(
         signum))
 
 
 def trap_ctrl_c_ctrl_break() -> None:
-    # - https://stackoverflow.com/questions/1112343/how-do-i-capture-sigint-in-python  # noqa
-    # - https://docs.python.org/3/library/signal.html#signal.SIG_IGN
-    # - https://msdn.microsoft.com/en-us/library/xdkz3x12.aspx
-    # - https://msdn.microsoft.com/en-us/library/windows/desktop/ms682541(v=vs.85).aspx  # noqa
-    #
-    # Under Windows, only options are:
-    #   SIGABRT     abnormal termination
-    #   SIGFPE      floating-point error
-    #   SIGILL      illegal instruction
-    #   SIGINT      CTRL+C signal           -- trapped here
-    #   SIGSEGV     illegal storage access
-    #   SIGTERM     termination request     -- trapped here
-    #   SIGBREAK    CTRL+BREAK              -- trapped here under Windows
-    #
-    # In Linux, you also find:
-    #   SIGBUS      bus error / unaligned access
-    #
-    # To ignore, can do:
-    #   signal.signal(signal.SIGINT, signal.SIG_IGN)  # SIG_IGN = "ignore me"
-    # or pass a specified handler, as below.
+    """
+    Prevent ``CTRL-C``, ``CTRL-BREAK``, and similar signals from doing
+    anything.
+    
+    See
+    
+    - https://docs.python.org/3/library/signal.html#signal.SIG_IGN
+    - https://msdn.microsoft.com/en-us/library/xdkz3x12.aspx
+    - https://msdn.microsoft.com/en-us/library/windows/desktop/ms682541(v=vs.85).aspx
+
+    Under Windows, the only options are:
+    
+      =========== ======================= =====================================
+      Signal      Meaning                 Comment
+      =========== ======================= =====================================
+      SIGABRT     abnormal termination
+      SIGFPE      floating-point error
+      SIGILL      illegal instruction
+      SIGINT      CTRL+C signal           -- trapped here
+      SIGSEGV     illegal storage access
+      SIGTERM     termination request     -- trapped here
+      SIGBREAK    CTRL+BREAK              -- trapped here under Windows
+      =========== ======================= =====================================
+
+    In Linux, you also find:
+
+      =========== =============================
+      Signal      Meaning
+      =========== =============================
+      SIGBUS      bus error / unaligned access
+      =========== =============================
+
+    To ignore, can do:
+    
+    .. code-block:: python
+    
+      signal.signal(signal.SIGINT, signal.SIG_IGN)  # SIG_IGN = "ignore me"
+      
+    or pass a specified handler, as in the code here.
+    """  # noqa
 
     signal.signal(signal.SIGINT, ctrl_c_trapper)
     signal.signal(signal.SIGTERM, sigterm_trapper)
